@@ -437,13 +437,15 @@ class GlueRunner(TaskRunner):
         logger.warning(f"num_labels: {self.num_labels}")
         if model_args.cl_alpha is None:
             self.model = MyGlueModel(
-                model_name_or_path=model_args.model_name_or_path if
-                model_args.model_name_or_path else model_args.checkpoint_path,
+                model_name_or_path=model_args.model_name_or_path
+                if model_args.model_name_or_path else os.path.join(
+                    model_args.checkpoint_path, "checkpoint"),
                 num_labels=self.num_labels)
         else:
             self.model = ContrastiveLearningGlueModel(
-                model_name_or_path=model_args.model_name_or_path if
-                model_args.model_name_or_path else model_args.checkpoint_path,
+                model_name_or_path=model_args.model_name_or_path
+                if model_args.model_name_or_path else os.path.join(
+                    model_args.checkpoint_path, "checkpoint"),
                 num_labels=self.num_labels,
                 cl_alpha=model_args.cl_alpha)
         #  config = self.transformer.config
